@@ -1,4 +1,4 @@
-from learning_loop_node.detector import BoxDetection, Detections
+from learning_loop_node.detector import BoxDetection, PointDetection, Detections
 from learning_loop_node import Detector, ModelInformation
 
 
@@ -12,5 +12,7 @@ class TestingDetector(Detector):
         pass
 
     def evaluate(self, image: bytes) -> Detections:
-
-        return Detections(box_detections=[BoxDetection('some_category_name', 1, 2, 3, 4, 'some_model', 42)])
+        return Detections(
+            box_detections=[BoxDetection('some_category_name', 1, 2, 3, 4, 'some_model', 42)],
+            point_detections=[PointDetection('some_category_name', 10, 12, 'some_model', 42)]
+        )
